@@ -65,8 +65,11 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   _messageTimerID = 0;
   _gtkFavesShouldBeImported = false;
 
-  setWindowTitle(GmicQt::pluginFullName());
+  _lastExecutionOK = true; // Overwritten by loadSettings()
+  _expandCollapseIcon = nullptr;
+  _newSession = true; // Overwritten by loadSettings()
 
+  setWindowTitle(GmicQt::pluginFullName());
   QStringList tsp = QIcon::themeSearchPaths();
   tsp.append(QString("/usr/share/icons/gnome"));
   QIcon::setThemeSearchPaths(tsp);
@@ -89,11 +92,11 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
 
   ui->tbExpandCollapse->setToolTip(tr("Expand/Collapse all"));
 
-  ui->logosLabel->setToolTip(tr("G'MIC (http://gmic.eu)<br/>"
-                                "GREYC (http://www.greyc.fr)<br/>"
-                                "CNRS (http://www.cnrs.fr)<br/>"
-                                "Normandy University (http://www.unicaen.fr)<br/>"
-                                "Ensicaen (http://www.ensicaen.fr)"));
+  ui->logosLabel->setToolTip(tr("G'MIC (https://gmic.eu)<br/>"
+                                "GREYC (https://www.greyc.fr)<br/>"
+                                "CNRS (https://www.cnrs.fr)<br/>"
+                                "Normandy University (https://www.unicaen.fr)<br/>"
+                                "Ensicaen (https://www.ensicaen.fr)"));
   ui->logosLabel->setPixmap(QPixmap(":resources/logos.png"));
 
   ui->tbSelectionMode->setToolTip(tr("Selection mode"));
@@ -113,13 +116,13 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
 
   ui->zoomLevelSelector->setPreviewWidget(ui->previewWidget);
 
-  QAction * searchAction = new QAction(this);
+  auto searchAction = new QAction(this);
   searchAction->setShortcut(QKeySequence::Find);
   searchAction->setShortcutContext(Qt::ApplicationShortcut);
   connect(searchAction, SIGNAL(triggered(bool)), ui->searchField, SLOT(setFocus()));
   addAction(searchAction);
 
-  QAction * togglePreviewAction = new QAction(this);
+  auto togglePreviewAction = new QAction(this);
   togglePreviewAction->setShortcut(QKeySequence("Ctrl+P"));
   togglePreviewAction->setShortcutContext(Qt::ApplicationShortcut);
   connect(togglePreviewAction, SIGNAL(triggered(bool)), ui->cbPreview, SLOT(toggle()));
@@ -132,7 +135,7 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   addAction(searchAction);
 
   ui->tbUpdateFilters->setShortcut(QKeySequence("Ctrl+R"));
-  QAction * updateFiltersAction = new QAction(this);
+  auto updateFiltersAction = new QAction(this);
   updateFiltersAction->setShortcut(QKeySequence("F5"));
   updateFiltersAction->setShortcutContext(Qt::ApplicationShortcut);
   connect(updateFiltersAction, SIGNAL(triggered(bool)), ui->tbUpdateFilters, SLOT(click()));
@@ -143,7 +146,7 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   ui->verticalSplitter->setStretchFactor(0, 5);
   ui->verticalSplitter->setStretchFactor(0, 1);
 
-  QPalette p = qApp->palette();
+  QPalette p = QGuiApplication::palette();
   DialogSettings::UnselectedFilterTextColor = p.color(QPalette::Disabled, QPalette::WindowText);
 
   _filtersPresenter = new FiltersPresenter(this);
@@ -216,7 +219,7 @@ void MainWindow::setDarkTheme()
   p.setColor(QPalette::Text, QColor(255, 255, 255));
   p.setColor(QPalette::ButtonText, QColor(255, 255, 255));
   p.setColor(QPalette::WindowText, QColor(255, 255, 255));
-  QColor linkColor(100, 100, 100);
+  QColor linkColor(130, 130, 150);
   linkColor = linkColor.lighter();
   p.setColor(QPalette::Link, linkColor);
   p.setColor(QPalette::LinkVisited, linkColor);
@@ -251,7 +254,6 @@ void MainWindow::setDarkTheme()
                       "QGroupBox { border: 1px solid #808080; margin-top: 4ex; } "
                       "QFileDialog QAbstractItemView { background: #505050; } "
                       "QComboBox:editable { background: #505050; } "
-                      "QComboBox::disabled { background: rgb(40,40,40); } "
                       "QProgressBar { background: #505050; }";
   qApp->setStyleSheet(css);
   ui->inOutSelector->setDarkTheme();
@@ -289,7 +291,7 @@ void MainWindow::onUpdateDownloadsFinished(int status)
   buildFiltersTree();
   ui->tbUpdateFilters->setEnabled(true);
   if (!_filtersPresenter->currentFilter().hash.isEmpty()) {
-    ui->previewWidget->sendUpdateRequest();
+    ui->previewWidget->sendUpdateRequest(); // FIXME : Select filter
   }
 }
 
@@ -303,6 +305,7 @@ void MainWindow::buildFiltersTree()
   _filtersPresenter->clear();
   _filtersPresenter->readFilters();
   _filtersPresenter->readFaves();
+  _filtersPresenter->restoreFaveHashLinksAfterCaseChange(); // TODO : Remove, some day!
   if (_gtkFavesShouldBeImported) {
     _filtersPresenter->importGmicGTKFaves();
     _filtersPresenter->saveFaves();
@@ -328,7 +331,9 @@ void MainWindow::onStartupFiltersUpdateFinished(int status)
 
   ui->progressInfoWidget->stopAnimationAndHide();
   if (status == Updater::SomeUpdatesFailed) {
-    showUpdateErrors();
+    if (DialogSettings::notifyFailedStartupUpdate()) {
+      showMessage(tr("Filters update could not be achieved"), 3000);
+    }
   } else if (status == Updater::UpdateSuccessful) {
     if (Updater::getInstance()->someNetworkUpdateAchieved()) {
       showMessage(tr("Filter definitions have been updated."), 4000);
@@ -438,7 +443,7 @@ void MainWindow::timerEvent(QTimerEvent * e)
   e->ignore();
 }
 
-void MainWindow::showMessage(QString text, int ms)
+void MainWindow::showMessage(const QString & text, int ms)
 {
   clearMessage();
   if (!text.isEmpty() && ms) {
@@ -452,7 +457,7 @@ void MainWindow::showUpdateErrors()
   QString message(tr("The update could not be achieved<br>"
                      "because of the following errors:<br>"));
   QList<QString> errors = Updater::getInstance()->errorMessages();
-  for (QString s : errors) {
+  for (const QString s : errors) {
     message += QString("<br/>%1").arg(s);
   }
   QMessageBox::information(this, tr("Update error"), message);
@@ -560,7 +565,7 @@ void MainWindow::onPreviewKeypointsEvent(unsigned int flags, unsigned long time)
   } else {
     ui->filterParams->setKeypoints(ui->previewWidget->keypoints(), false);
     if ((flags & PreviewWidget::KeypointBurstEvent)) {
-      const ulong t = (ulong)_processor.lastPreviewFilterExecutionDurationMS();
+      const auto t = static_cast<ulong>(_processor.lastPreviewFilterExecutionDurationMS());
       const bool keypointBurstEnabled = (t <= KEYPOINTS_INTERACTIVE_LOWER_DELAY_MS) ||
                                         ((t <= KEYPOINTS_INTERACTIVE_UPPER_DELAY_MS) && ((ulong)_processor.averagePreviewFilterExecutionDuration() <= KEYPOINTS_INTERACTIVE_MIDDLE_DELAY_MS));
       ulong msSinceLastBurstEvent = time - _lastPreviewKeypointBurstUpdateTime;
@@ -575,6 +580,7 @@ void MainWindow::onPreviewKeypointsEvent(unsigned int flags, unsigned long time)
 void MainWindow::onPreviewImageAvailable()
 {
   ui->filterParams->setValues(_processor.gmicStatus(), false);
+  ui->filterParams->setVisibilityStates(_processor.parametersVisibilityStates());
   // Make sure keypoint positions are synchronized with gmic status
   if (ui->filterParams->hasKeypoints()) {
     ui->previewWidget->setKeypoints(ui->filterParams->keypoints());
@@ -587,7 +593,7 @@ void MainWindow::onPreviewImageAvailable()
   }
 }
 
-void MainWindow::onPreviewError(QString message)
+void MainWindow::onPreviewError(const QString & message)
 {
   ui->previewWidget->setPreviewErrorMessage(message);
   ui->previewWidget->enableRightClick();
@@ -634,7 +640,7 @@ void MainWindow::processImage()
   _processor.execute();
 }
 
-void MainWindow::onFullImageProcessingError(QString message)
+void MainWindow::onFullImageProcessingError(const QString & message)
 {
   ui->progressInfoWidget->stopAnimationAndHide();
   QMessageBox::warning(this, tr("Error"), message, QMessageBox::Close);
@@ -672,6 +678,7 @@ void MainWindow::onFullImageProcessingDone()
   enableWidgetList(true);
   ui->previewWidget->update();
   ui->filterParams->setValues(_processor.gmicStatus(), false);
+  ui->filterParams->setVisibilityStates(_processor.parametersVisibilityStates());
   if ((_pendingActionAfterCurrentProcessing == OkAction || _pendingActionAfterCurrentProcessing == CloseAction)) {
     close();
   } else {
@@ -696,7 +703,7 @@ void MainWindow::expandOrCollapseFolders()
   }
 }
 
-void MainWindow::search(QString text)
+void MainWindow::search(const QString & text)
 {
   _filtersPresenter->applySearchCriterion(text);
 }
@@ -756,6 +763,7 @@ void MainWindow::onProgressionWidgetCancelClicked()
 void MainWindow::onReset()
 {
   if (!_filtersPresenter->currentFilter().hash.isEmpty() && _filtersPresenter->currentFilter().isAFave) {
+    ui->filterParams->setVisibilityStates(_filtersPresenter->currentFilter().defaultVisibilityStates);
     ui->filterParams->setValues(_filtersPresenter->currentFilter().defaultParameterValues, true);
     return;
   }
@@ -784,6 +792,7 @@ void MainWindow::saveCurrentParameters()
   QString hash = ui->filterParams->filterHash();
   if (!hash.isEmpty() && (hash == ui->filterParams->filterHash())) {
     ParametersCache::setValues(hash, ui->filterParams->valueStringList());
+    ParametersCache::setVisibilityStates(hash, ui->filterParams->visibilityStates());
     ParametersCache::setInputOutputState(hash, ui->inOutSelector->state());
   }
 }
@@ -867,12 +876,12 @@ void MainWindow::loadSettings()
     } else {
       QDesktopWidget desktop;
       QRect screenSize = desktop.availableGeometry();
-      screenSize.setWidth(screenSize.width() * 0.66);
-      screenSize.setHeight(screenSize.height() * 0.66);
+      screenSize.setWidth(static_cast<int>(screenSize.width() * 0.66));
+      screenSize.setHeight(static_cast<int>(screenSize.height() * 0.66));
       screenSize.moveCenter(desktop.availableGeometry().center());
       setGeometry(screenSize);
       int w = screenSize.width();
-      ui->splitter->setSizes(QList<int>() << (w * 0.4) << (w * 0.2) << (w * 0.4));
+      ui->splitter->setSizes(QList<int>() << static_cast<int>(w * 0.4) << static_cast<int>(w * 0.2) << static_cast<int>(w * 0.4));
     }
   }
 
@@ -900,7 +909,7 @@ void MainWindow::setPreviewPosition(MainWindow::PreviewPosition position)
   }
   _previewPosition = position;
 
-  QHBoxLayout * layout = dynamic_cast<QHBoxLayout *>(ui->belowPreviewWidget->layout());
+  auto layout = dynamic_cast<QHBoxLayout *>(ui->belowPreviewWidget->layout());
   if (layout) {
     layout->removeWidget(ui->belowPreviewPadding);
     layout->removeWidget(ui->logosLabel);
@@ -985,7 +994,11 @@ void MainWindow::activateFilter(bool resetZoom)
     if (savedValues.isEmpty() && filter.isAFave) {
       savedValues = filter.defaultParameterValues;
     }
-    if (!ui->filterParams->build(filter.name, filter.hash, filter.parameters, savedValues)) {
+    QList<int> savedVisibilityStates = ParametersCache::getVisibilityStates(filter.hash);
+    if (savedVisibilityStates.isEmpty() && filter.isAFave) {
+      savedVisibilityStates = filter.defaultVisibilityStates;
+    }
+    if (!ui->filterParams->build(filter.name, filter.hash, filter.parameters, savedValues, savedVisibilityStates)) {
       _filtersPresenter->setInvalidFilter();
       ui->previewWidget->setKeypoints(KeypointList());
     } else {
@@ -1009,7 +1022,7 @@ void MainWindow::activateFilter(bool resetZoom)
 
 void MainWindow::setNoFilter()
 {
-  ui->filterParams->setNoFilter();
+  ui->filterParams->setNoFilter(_filtersPresenter->errorMessage());
   ui->previewWidget->disableRightClick();
   ui->previewWidget->setKeypoints(KeypointList());
   ui->inOutSelector->hide();
@@ -1019,8 +1032,7 @@ void MainWindow::setNoFilter()
   ui->tbResetParameters->setVisible(false);
   ui->zoomLevelSelector->showWarning(false);
   _okButtonShouldApply = false;
-
-  ui->tbRemoveFave->setEnabled(false);
+  ui->tbRemoveFave->setEnabled(_filtersPresenter->danglingFaveIsSelected());
   ui->tbRenameFave->setEnabled(false);
 }
 
@@ -1087,7 +1099,7 @@ void MainWindow::onAddFave()
     return;
   }
   saveCurrentParameters();
-  _filtersPresenter->addSelectedFilterAsNewFave(ui->filterParams->valueStringList(), ui->inOutSelector->state());
+  _filtersPresenter->addSelectedFilterAsNewFave(ui->filterParams->valueStringList(), ui->filterParams->visibilityStates(), ui->inOutSelector->state());
 }
 void MainWindow::onRemoveFave()
 {
@@ -1129,7 +1141,7 @@ void MainWindow::onSettingsClicked()
   DialogSettings dialog(this);
   dialog.exec();
   bool previewPositionChanged = (_previewPosition != DialogSettings::previewPosition());
-  setPreviewPosition(dialog.previewPosition());
+  setPreviewPosition(DialogSettings::previewPosition());
   if (previewPositionChanged) {
     splitterSizes.clear();
     if (_previewPosition == PreviewOnLeft) {
