@@ -52,7 +52,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 257
+#define gmic_version 262
 
 #ifndef gmic_pixel_type
 #define gmic_pixel_type float
@@ -166,6 +166,7 @@ namespace cimg_library {
 #error "[gmic] *** Error *** File 'CImg.h' has been already included (should have been done first in file 'gmic.h')."
 #endif
 #define cimg_plugin "gmic.cpp"
+#define cimglist_plugin "gmic.cpp"
 
 #ifdef cimg_use_abort
 inline bool *gmic_abort_ptr(bool *const p_is_abort);
@@ -271,11 +272,11 @@ struct gmic {
   gmic& add_commands(std::FILE *const file, const char *const filename=0,
                      unsigned int *count_new=0, unsigned int *count_replaced=0);
 
-  gmic_image<char> callstack2string(const bool is_debug=false) const;
+  gmic_image<char> callstack2string(const bool _is_debug=false) const;
   gmic_image<char> callstack2string(const gmic_image<unsigned int>& callstack_selection,
-                                    const bool is_debug=false) const;
+                                    const bool _is_debug=false) const;
   gmic_image<char> callstack2string(const gmic_image<unsigned int>* callstack_selection,
-                                    const bool is_debug=false) const;
+                                    const bool _is_debug=false) const;
 
   gmic_image<unsigned int> selection2cimg(const char *const string, const unsigned int indice_max,
                                           const gmic_list<char>& names, const char *const command,
@@ -294,7 +295,7 @@ struct gmic {
                              const gmic_list<T>& images);
 
   gmic& print(const char *format, ...);
-  gmic& error(const char *format, ...);
+  gmic& error(const bool output_header, const char *format, ...);
   gmic& debug(const char *format, ...);
 
   template<typename T>
@@ -304,6 +305,10 @@ struct gmic {
 				   const unsigned int *const variables_sizes,
                                    const gmic_image<unsigned int> *const command_selection,
                                    const bool is_image_expr);
+
+  template<typename T>
+  void wait_threads(void *const p_gmic_threads, const bool try_abort, const T foo);
+
   template<typename T>
   gmic& print(const gmic_list<T>& list, const gmic_image<unsigned int> *const callstack_selection,
 	      const char *format, ...);
@@ -313,9 +318,13 @@ struct gmic {
              const bool force_visible, const char *format, ...);
 
   template<typename T>
-  gmic& error(const gmic_list<T>& list, const gmic_image<unsigned int> *const callstack_selection,
+  gmic& error(const bool output_header, const gmic_list<T>& list,
+              const gmic_image<unsigned int> *const callstack_selection,
 	      const char *const command, const char *format, ...);
 
+  template<typename T>
+  bool check_cond(const char *const expr, gmic_list<T>& images, const char *const command);
+
   template<typename T>
   gmic& debug(const gmic_list<T>& list, const char *format, ...);
 
@@ -374,19 +383,19 @@ struct gmic {
   static gmic_list<void*> list_p_is_abort;
   static bool is_display_available;
 
-  gmic_list<char> *const commands, *const commands_names, *const commands_has_arguments,
-    *const _variables, *const _variables_names, **const variables, **const variables_names,
+  gmic_list<char> *commands, *commands_names, *commands_has_arguments,
+    *_variables, *_variables_names, **variables, **variables_names,
     commands_files, callstack;
   gmic_image<unsigned int> dowhiles, fordones, repeatdones;
   gmic_image<unsigned char> light3d;
+  gmic_image<void*> display_windows;
   gmic_image<char> status;
-  void *display_windows;
 
   float focale3d, light3d_x, light3d_y, light3d_z, specular_lightness3d, specular_shininess3d, _progress, *progress;
   unsigned long reference_time;
   unsigned int nb_dowhiles, nb_fordones, nb_repeatdones, nb_carriages, debug_filename, debug_line, cimg_exception_mode;
   int verbosity,render3d, renderd3d;
-  bool is_released, is_debug, is_running, is_start, is_return, is_quit, is_double3d, is_debug_info, check_elif,
+  bool is_released, is_debug, is_running, is_start, is_return, is_quit, is_double3d, is_debug_info,
     _is_abort, *is_abort, is_abort_thread;
   const char *starting_commands_line;
 };
